(ast->jena opts ast)Given an opts map and a conformed Flint ast, convert it into a
Jena instance or a coll thereof. Does so by performing tree traversal
of ast and applying ast-node->jena (and the -pre and -post
functions, when applicable) to each AST node.
Given an `opts` map and a conformed Flint `ast`, convert it into a Jena instance or a coll thereof. Does so by performing tree traversal of `ast` and applying `ast-node->jena` (and the `-pre` and `-post` functions, when applicable) to each AST node.
(ast-node->jena opts ast-node)Given the ast-node, return a Jena query/update builder instance.
Applies and/or mutates opts whenever needed.
Given the `ast-node`, return a Jena query/update builder instance. Applies and/or mutates `opts` whenever needed.
(ast-node->jena-post opts ast-node)Dispatching on the ast-node keyword, perform an action at the node
after ast-node->jena is called. Typically used for side effects.
Dispatching on the `ast-node` keyword, perform an action at the node **after** `ast-node->jena` is called. Typically used for side effects.
(ast-node->jena-pre opts ast-node)Dispatching on the ast-node keyword, perform an action at the node
before ast-node->jena is called. Typically used for side effects.
Dispatching on the `ast-node` keyword, perform an action at the node **before** `ast-node->jena` is called. Typically used for side effects.
(ast-node-dispatch ast-node)(ast-node-dispatch _ ast-node)(ast-node-dispatch _ _ ast-node)Multi-method dispatch based on ast-node's keyword.
Multi-method dispatch based on `ast-node`'s keyword.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |