com.yetanalytics.flint-jena.query


create-queryclj

(create-query prologue {:keys [query-stack] :as opts} [query-type query-ast])

Create a new Query instance with the contents of prologue and query-ast and its type (SELECT, CONSTRUCT, etc.) set by query-type.

Create a new Query instance with the contents of `prologue` and `query-ast`
and its type (SELECT, CONSTRUCT, etc.) set by `query-type`.
sourceraw docstring

query-add!cljmultimethod

(query-add! query ast-node)

Add the ast-node, which should have been converted into a Jena object via ast/ast->jena, to query.

Add the `ast-node`, which should have been converted into a Jena object
via `ast/ast->jena`, to `query`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries