(create-query prologue {:keys [query-stack] :as opts} [query-type query-ast])Create a new Query instance with the contents of prologue and query-ast
and its type (SELECT, CONSTRUCT, etc.) set by query-type.
Create a new Query instance with the contents of `prologue` and `query-ast` and its type (SELECT, CONSTRUCT, etc.) set by `query-type`.
(query-add! query ast-node)Add the ast-node, which should have been converted into a Jena object
via ast/ast->jena, to query.
Add the `ast-node`, which should have been converted into a Jena object via `ast/ast->jena`, to `query`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |